==> glpi_0.80.7.orig.tar.gz: glpi/front/device.php <==
<?php
/*
 * @version $Id: device.php 17154 2012-01-24 11:27:36Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("device","w");

commonHeader($LANG['title'][30],$_SERVER['PHP_SELF'],"config","device");
echo "<div align='center'>";

$optgroup = Dropdown::getDeviceItemTypes();
Dropdown::showItemTypeMenu($LANG['title'][30], $optgroup);
Dropdown::showItemTypeList($optgroup);

echo "</div>";
commonFooter();

?>

==> glpi_0.83.31.orig.tar.gz: glpi/front/device.php <==
<?php
/*
 * @version $Id: device.php 17152 2012-01-24 11:22:16Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

Session::checkRight("device", "w");

Html::header(Toolbox::ucfirst($LANG['log'][18]),$_SERVER['PHP_SELF'],"config","device");
echo "<div align='center'>";

$optgroup = Dropdown::getDeviceItemTypes();
Dropdown::showItemTypeMenu(Toolbox::ucfirst($LANG['log'][18]), $optgroup);
Dropdown::showItemTypeList($optgroup);

echo "</div>";
Html::footer();
?>
